Maintainers
===========
- Trey Hunner
- Micah Denbraver
- Ross Mechanic

Authors
=======

- Aleksey Kladov
- Ben Lawson
- bradford281
- Buddy Lindsey, Jr.
- Brian Dixon
- Corey Bertram
- Damien Nozay
- Daniel Gilge
- Daniel Levy
- Daniel Roschka
- David Hite
- Eduardo Cuducos
- Florian Eßer
- George Vilches
- Grzegorz Bialy
- Hamish Downer
- James Pulec
- Joao Junior(@joaojunior)
- Joao Pedro Francese
- jofusa
- John Whitlock
- Jonathan Leroy
- Jonathan Sanchez
- Josh Fyne
- Klaas van Schelven
- Kris Neuharth
- Maciej "RooTer" Urbański
- Mark Davidoff
- Leticia Portella
- Martin Bachwerk
- Marty Alchin
- Mauricio de Abreu Antunes
- Micah Denbraver
- Miguel Vargas
- Nianpeng Li
- Phillip Marshall
- Rajesh Pappula
- Roberto Aguilar
- Rod Xavier Bondoc
- Ross Lote
- Ross Mechanic
- Ross Rogers
- Steven Klass
- Steeve Chailloux
- Trey Hunner
- Ulysses Vilela
- vnagendra
- Lucas Wiman
- Michael England
- Gregory Bataille
- Jesse Shapiro
- Kevin Foster
- Shane Engelman
- Ray Logel
- Nathan Villagaray-Carski
- Mike Spainhower
- Alexander Anikeev
- Kyle Seever
- Adnan Umer (@uadnan)
- Jonathan Zvesper (@zvesp)
- Matheus Cansian (@mscansian)
- Jim Gomez

Background
==========

This code originally comes from Pro Django, published by Apress, Inc.
in December 2008. The author of the book and primary author
of the code is Marty Alchin <marty@martyalchin.com>, who
may be found online at <http://martyalchin.com/>.

As part of the technical review process, additional code
modifications were provided by the technical reviewer,
George Vilches <gav@thataddress.com>.

This code was originally extended, licensed, and improved by
Corey Bertram <corey@qr7.com> with the permission of Marty Alchin.
